@@ -115,7 +115,7 @@ struct _VteCharAttributes {
         /*< private >*/
 	long row, column;
 	PangoColor fore, back;
-	guint underline:1, strikethrough:1;
+	guint underline:1, strikethrough:1, columns:4;
 };
 
 typedef gboolean (*VteSelectionFunc)(VteTerminal *terminal,
@@ -362,11 +362,6 @@ char *vte_terminal_get_text(VteTerminal *terminal,
 			    gpointer user_data,
 			    GArray *attributes) _VTE_GNUC_NONNULL(1) G_GNUC_MALLOC;
 _VTE_PUBLIC
-char *vte_terminal_get_text_include_trailing_spaces(VteTerminal *terminal,
-						    VteSelectionFunc is_selected,
-						    gpointer user_data,
-						    GArray *attributes) _VTE_GNUC_NONNULL(1) G_GNUC_MALLOC;
-_VTE_PUBLIC
 char *vte_terminal_get_text_range(VteTerminal *terminal,
 				  glong start_row, glong start_col,
 				  glong end_row, glong end_col,
